==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesSt.php <==
<?php
/** Southern Sotho (Sesotho)
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 */

$messages = array(
# Dates
'sunday'    => 'Sontaha',
'monday'    => 'Mantaha',
'tuesday'   => 'Labobedi',
'wednesday' => 'Laboraro',
'thursday'  => 'Labone',
'friday'    => 'Labohlano',
'saturday'  => 'Moqebelo',
'january'   => 'Pherekgong',
'february'  => 'Hlakola',
'march'     => 'Hlakubele',
'april'     => 'Mmesa',
'may_long'  => 'Motsheanong',
'june'      => 'Phupjane',
'july'      => 'Phupu',
'august'    => 'Phato',
'september' => 'Lwetse',
'october'   => 'Mphalane',
'november'  => 'Pudungwana',
'december'  => 'Tshitwe',
'may-gen'   => 'Motsheanong',
'jan'       => 'Phere',
'feb'       => 'Hlako',
'mar'       => 'Hlaku',
'apr'       => 'Mmesa',
'may'       => 'Motshe',
'jun'       => 'Phupjane',
'jul'       => 'Phupu',
'aug'       => 'Phato',
'sep'       => 'Lwetse',
'oct'       => 'Mphala',
'nov'       => 'Pudu',
'dec'       => 'Tshitwe',

# Categories related messages
'category_header' => 'Dingolwa tse mokgeng wa "$1"',

'mypage'     => 'Leqephe la ka',
'mytalk'     => 'Leqephe la ka la moqoqo',
'navigation' => 'Eya ho',

'returnto'       => 'Kgutlela ho $1.',
'tagline'        => 'E tswa ho {{SITENAME}}',
'search'         => 'Fuputsa',
'history'        => 'Nalane',
'history_short'  => 'Nalane',
'info_short'     => 'Tlhahiso-leseding',
'newpage'        => 'Leqephe le letjha',
'talkpage'       => 'Qoqa ka leqephe lena',
'talk'           => 'Moqoqo',
'categorypage'   => 'Mpontshe leqephe la mekga',
'otherlanguages' => 'Ka maleme a mang',
'jumptosearch'   => 'phuputso',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'faq'                  => 'Dipotso-mehla',
'mainpage'             => 'Leqephe la pele',
'mainpage-description' => 'Leqephe la pele',
'portal'               => 'Potjho e kopano',
'portal-url'           => 'Project:Potjho e kopano',

'retrievedfrom'   => 'E tswa ho "$1"',
'newmessageslink' => 'melaetsa e metjha',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Sengolwa',
'nstab-mediawiki' => 'Molaetsa',
'nstab-help'      => 'Leqephe la thusa',
'nstab-category'  => 'Mokga',

# Login and logout pages
'yourpasswordagain'  => 'Ngola lepetjo hape',
'remembermypassword' => 'O nkgopole',
'nologinlink'        => 'Ingodisetse',
'createaccount'      => 'Ingodisetse',
'gotaccount'         => 'O se o ingodisitse? $1.',
'createaccountmail'  => 'ka e-mail',
'badretype'          => 'Mapetjo a mabedi o a ngotseng ha a tshwane.',
'mailmypassword'     => 'Nthomele password ya ka ka email',

# Password reset dialog
'oldpassword' => 'Lepetjo la kgale:',
'newpassword' => 'Lepetjo le letjha:',
'retypenew'   => 'Ngola lepetjo le letjha hape:',

# Edit pages
'savearticle'  => 'Le boloke',
'showpreview'  => 'Mpontshe hore le tlo ba jwang',
'showdiff'     => 'Mpontshe hore ho tlo fetoha eng',
'accmailtitle' => 'Lepetjo le rometswe.',
'accmailtext'  => 'Lepetjo la "$1" le se le rometswe ho $2.',
'note'         => "'''Ela hloko:'''",

# Search results
'powersearch' => 'Fuputsa',

# Preferences page
'changepassword'    => 'Fetola lepetjo',
'searchresultshead' => 'Phuputso',
'allowemail'        => 'Dumella batho ba bang hore ba nthomelle di-email',

# MIME search
'download' => 'Jarolla',

# Random page
'randompage' => 'Mpontshe leqephe le leng le le leng',

# Statistics
'statistics' => 'Dipalopalo',

# Miscellaneous special pages
'mostcategories' => 'Dingolwa tse mekga e mengata',
'shortpages'     => 'Maqephe a makgutshwane',
'longpages'      => 'Maqephe a matelele',
'newpages'       => 'Maqephe a matjha',

# Special:AllPages
'allpages' => 'Maqephe ohle',

# Special:Categories
'categories'         => 'Mekga',
'categoriespagetext' => 'Wiki e na le mekga ena',

# E-mail user
'emailuser'     => 'Romela motho enwa email',
'emailfrom'     => 'E tswa ho',
'emailto'       => 'Ho',
'emailsubject'  => 'Ka',
'emailmessage'  => 'O re',
'emailsend'     => 'E romele',
'emailsent'     => 'E rometswe',
'emailsenttext' => 'Email ya molaetsa wa hao e se e rometswe.',

# Contributions
'contributions' => 'Tse ngotsweng ke motho enwa',
'mycontris'     => 'Tse ngotsweng ke nna',

# Block/unblock
'ipbreason'     => 'Lebaka',
'infiniteblock' => 'ho eya ho ile',

# Namespace 8 related
'allmessagesname'    => 'Lebitso',
'allmessagesdefault' => 'Se neng se ngotswe pele',
'allmessagescurrent' => 'Se ngotsweng hona jwale',

# Info page
'infosubtitle' => 'Tlhahiso-leseding ka leqephe',

);

==> mediawiki-1.15.5p0.tgz: mediawiki/languages/messages/MessagesSt.php <==
<?php
/** Southern Sotho (Sesotho)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 */

$messages = array(
# Dates
'sunday'    => 'Sontaha',
'monday'    => 'Mantaha',
'tuesday'   => 'Labobedi',
'wednesday' => 'Laboraro',
'thursday'  => 'Labone',
'friday'    => 'Labohlano',
'saturday'  => 'Moqebelo',
'january'   => 'Pherekgong',
'february'  => 'Hlakola',
'march'     => 'Hlakubele',
'april'     => 'Mmesa',
'may_long'  => 'Motsheanong',
'june'      => 'Phupjane',
'july'      => 'Phupu',
'august'    => 'Phato',
'september' => 'Lwetse',
'october'   => 'Mphalane',
'november'  => 'Pudungwana',
'december'  => 'Tshitwe',
'may-gen'   => 'Motsheanong',
'jan'       => 'Phere',
'feb'       => 'Hlako',
'mar'       => 'Hlaku',
'apr'       => 'Mmesa',
'may'       => 'Motshe',
'jun'       => 'Phupjane',
'jul'       => 'Phupu',
'aug'       => 'Phato',
'sep'       => 'Lwetse',
'oct'       => 'Mphala',
'nov'       => 'Pudu',
'dec'       => 'Tshitwe',

# Categories related messages
'category_header' => 'Dingolwa tse mokgeng wa "$1"',

'mypage'     => 'Leqephe la ka',
'mytalk'     => 'Leqephe la ka la moqoqo',
'navigation' => 'Eya ho',

'returnto'       => 'Kgutlela ho $1.',
'tagline'        => 'E tswa ho {{SITENAME}}',
'search'         => 'Fuputsa',
'history'        => 'Nalane',
'history_short'  => 'Nalane',
'info_short'     => 'Tlhahiso-leseding',
'newpage'        => 'Leqephe le letjha',
'talkpage'       => 'Qoqa ka leqephe lena',
'talk'           => 'Moqoqo',
'categorypage'   => 'Mpontshe leqephe la mekga',
'otherlanguages' => 'Ka maleme a mang',
'jumptosearch'   => 'phuputso',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'faq'                  => 'Dipotso-mehla',
'mainpage'             => 'Leqephe la pele',
'mainpage-description' => 'Leqephe la pele',
'portal'               => 'Potjho e kopano',
'portal-url'           => 'Project:Potjho e kopano',

'retrievedfrom'   => 'E tswa ho "$1"',
'newmessageslink' => 'melaetsa e metjha',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Sengolwa',
'nstab-mediawiki' => 'Molaetsa',
'nstab-help'      => 'Leqephe la thusa',
'nstab-category'  => 'Mokga',

# Login and logout pages
'yourpasswordagain'  => 'Ngola lepetjo hape',
'remembermypassword' => 'O nkgopole',
'nologinlink'        => 'Ingodisetse',
'createaccount'      => 'Ingodisetse',
'gotaccount'         => "O se o ingodisitse? '''$1'''.",
'createaccountmail'  => 'ka e-mail',
'badretype'          => 'Mapetjo a mabedi o a ngotseng ha a tshwane.',
'mailmypassword'     => 'Nthomele password ya ka ka email',

# Password reset dialog
'oldpassword' => 'Lepetjo la kgale:',
'newpassword' => 'Lepetjo le letjha:',
'retypenew'   => 'Ngola lepetjo le letjha hape:',

# Edit pages
'savearticle'  => 'Le boloke',
'showpreview'  => 'Mpontshe hore le tlo ba jwang',
'showdiff'     => 'Mpontshe hore ho tlo fetoha eng',
'accmailtitle' => 'Lepetjo le rometswe.',
'accmailtext'  => 'Lepetjo la "$1" le se le rometswe ho $2.',
'note'         => "'''Ela hloko:'''",

# Search results
'powersearch' => 'Fuputsa',

# Preferences page
'changepassword'    => 'Fetola lepetjo',
'searchresultshead' => 'Phuputso',
'allowemail'        => 'Dumella batho ba bang hore ba nthomelle di-email',

# MIME search
'download' => 'Jarolla',

# Random page
'randompage' => 'Mpontshe leqephe le leng le le leng',

# Statistics
'statistics' => 'Dipalopalo',

# Miscellaneous special pages
'mostcategories' => 'Dingolwa tse mekga e mengata',
'shortpages'     => 'Maqephe a makgutshwane',
'longpages'      => 'Maqephe a matelele',
'newpages'       => 'Maqephe a matjha',

# Special:AllPages
'allpages' => 'Maqephe ohle',

# Special:Categories
'categories'         => 'Mekga',
'categoriespagetext' => 'Wiki e na le mekga ena',

# E-mail user
'emailuser'     => 'Romela motho enwa email',
'emailfrom'     => 'E tswa ho',
'emailto'       => 'Ho',
'emailsubject'  => 'Ka',
'emailmessage'  => 'O re',
'emailsend'     => 'E romele',
'emailsent'     => 'E rometswe',
'emailsenttext' => 'Email ya molaetsa wa hao e se e rometswe.',

# Contributions
'contributions' => 'Tse ngotsweng ke motho enwa',
'mycontris'     => 'Tse ngotsweng ke nna',

# Block/unblock
'ipbreason'     => 'Lebaka',
'infiniteblock' => 'ho eya ho ile',

# Namespace 8 related
'allmessagesname'    => 'Lebitso',
'allmessagesdefault' => 'Se neng se ngotswe pele',
'allmessagescurrent' => 'Se ngotsweng hona jwale',

# Info page
'infosubtitle' => 'Tlhahiso-leseding ka leqephe',

);
